{% load i18n %}

<h2>{% trans "Options" %}</h2>
<form action="{% url lfs_manage_save_voucher_options %}"
      method="post">

    {% include "manage/lfs_form.html" %}
    
    <div class="buttons">
        <input class="padding-top ajax-save-button button"
               type="submit"
               value='{% trans "Save options" %}'
    </div>

</form>

