{% load i18n %}

<h2 class="navigation-title">
    {% trans "Shipping methods" %}
</h2>

<div class="navigation-body">
    {% for shipping_method in shipping_methods %}
        <div>
            <a class="selectable {% ifequal current_id shipping_method.id %}selected{% endifequal %}"
               href="{% url lfs.manage.views.manage_shipping_method shipping_method.id %}">
                {{shipping_method.name}}
            </a>
        </div>
    {% endfor %}
</div>