{% load i18n %}
{% load lfs_manage_tags %}

<h2>{% trans 'Products' %}</h2>
<form id="filter-products-form"
      action="{% url lfs_pg_products_inline property_group.id %}"
      onsubmit="return false">
    <input class="refresh-on-keyup" type="text" name="filter"/>    
    {% category_filter "refresh-on-change" "products_category_filter" %}
</form>

<div id="products-inline">
    {{ products_inline }}
</div>