{% load i18n %}
{% load sql %}
{% load adminmedia %}

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
    <head>

        <title>{% block title %}{% endblock %}</title>
        <link rel="shortcut icon" href="{{ STATIC_URL }}img/favicon.ico" type="image/ico" />

        <link rel="stylesheet" type="text/css" href="{% admin_media_prefix %}css/widgets.css" />
        <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/lfs.manage.css" />
        <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}jquery-ui-1.8.13.custom/css/smoothness/jquery-ui-1.8.13.custom.css" />
        <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}jquery/jquery.jgrowl.css" />
        <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}jquery/superfish/superfish.css" />

        <script type="text/javascript">
            window.__admin_media_prefix__ = "{% filter escapejs %}{% admin_media_prefix %}{% endfilter %}";
        </script>

        <script type="text/javascript" src="/admin/jsi18n/"></script>
        <script type="text/javascript" src="{% admin_media_prefix %}js/core.js"></script>
        <script type="text/javascript" src="{% admin_media_prefix %}js/calendar.js"></script>
        <script type="text/javascript" src="{% admin_media_prefix %}js/admin/DateTimeShortcuts.js"></script>
        <script type="text/javascript" src="{% admin_media_prefix %}js/urlify.js"></script>

        <script type="text/javascript" src="{{ STATIC_URL }}jquery/jquery-1.6.1.min.js"></script>
        <script type="text/javascript" src="{{ STATIC_URL }}jquery-ui-1.8.13.custom/js/jquery-ui-1.8.13.custom.min.js"></script>
        <script type="text/javascript" src="{{ STATIC_URL }}jquery/jquery.ui.nestedSortable.js"></script>

        <script type="text/javascript" src="{{ STATIC_URL }}tiny_mce-3.4.2/jquery.tinymce.js"></script>
        <script type="text/javascript" src="{{ STATIC_URL }}js/lfs_tinymce.js"></script>

        <script type="text/javascript" src="{{ STATIC_URL }}jquery/jquery.fileupload-4.2.1/jquery.fileupload-ui.js"></script>
        <script type="text/javascript" src="{{ STATIC_URL }}jquery/jquery.fileupload-4.2.1/jquery.fileupload.js"></script>

        <script type="text/javascript" src="{{ STATIC_URL }}jquery/jquery.form.pack.js"></script>
        <script type="text/javascript" src="{{ STATIC_URL }}jquery/jquery.jgrowl_minimized.js"></script>
        <script type="text/javascript" src="{{ STATIC_URL }}jquery/jquery.cookie.pack.js"></script>

        <script type="text/javascript" src="{{ STATIC_URL }}jquery/superfish/superfish.js"></script>
        <script type="text/javascript" src="{{ STATIC_URL }}js/lfs.manage.js"></script>

        {% block javascript %}{% endblock %}

    </head>
    <body class="{% block section %}{% endblock %}">
        {# {% dbinfo %} #}

        <div class="lfs-header">
            <div class="logo">
                <a href="{% url lfs_shop_view %}">
                    <img src="{{ STATIC_URL }}/img/logo_management.jpg"
                         alt="LFS"
                         title="LFS - Lightning Fast Shop"/>
                </a>
            </div>
            <div class="username">
                {% if user.is_authenticated %}
                    {% if user.last_name %}
                        <span>{{user.first_name}} {{user.last_name}}</span>
                    {% else %}
                        <span>{{ user.username }}</span>
                    {% endif %}
                    | <a class="logout"
                         href="/logout">{% trans 'Logout' %}</a>
                {% else %}
                    <a href="/login">{% trans 'Login' %}</a>
                {% endif %}
            </div>

            <table class="top-menu"
                   width="100%"
                   cellpadding="0" cellspacing="0">
                <tr>
                    <td>
                        <ul class="sf-menu"
                            width="100%">
                            <li><a>{% trans 'Shop' %}</a>
                                <ul>
                                    <li><a href="{% url lfs_manage_actions %}">{% trans 'Actions' %}</a></li>
                                    <li><a href="{% url lfs_manage_delivery_times %}">{% trans 'Delivery Times' %}</a></li>
                                    <li><a href="{% url lfs_manage_discounts %}">{% trans 'Discounts' %}</a></li>
                                    <li><a href="{% url lfs_manufacturer_dispatcher %}">{% trans 'Manufacturers' %}</a></li>
                                    <li><a href="{% url lfs_manage_payment %}">{% trans 'Payment Methods' %}</a></li>
                                    <li><a href="{% url lfs_manage_shop %}">{% trans 'Preferences' %}</a></li>
                                    <li><a href="{% url lfs.manage.views.manage_shipping %}">{% trans 'Shipping Methods' %}</a></li>
                                    <li><a href="{% url lfs_manage_taxes %}">{% trans 'Taxes' %}</a></li>
                                </ul>

                            </li>
                            <li><a>{% trans 'Catalog' %}</a>
                                <ul>
                                    <li><a href="{% url lfs_manage_categories %}">{% trans 'Categories' %}</a></li>
                                    <li><a href="{% url lfs_manage_product_dispatcher %}">{% trans 'Products' %}</a></li>
                                    <li><a href="{% url lfs_manage_products %}">{% trans 'Products Overview' %}</a></li>
                                </ul>
                            </li>
                            <li><a>{% trans 'Properties' %}</a>
                                <ul>
                                    <li><a href="{% url lfs_manage_shop_properties %}">{% trans 'Properties' %}</a></li>
                                    <li><a href="{% url lfs_manage_property_groups %}">{% trans 'Property Groups' %}</a></li>
                                </ul>
                            </li>
                            <li>
                                <a>{% trans 'HTML' %}</a>
                                <ul>
                                    <li><a href="{% url lfs_manage_pages %}">{% trans 'Pages' %}</a></li>
                                    <li><a href="{% url lfs_manage_static_blocks %}">{% trans 'Static blocks' %}</a></li>
                                </ul>
                            </li>
                            <li><a>{% trans 'Customers' %}</a>
                                <ul>
                                    <li><a href="{% url lfs_manage_carts %}">{% trans 'Carts' %}</a></li>
                                    <li><a href="{% url lfs_manage_customers %}">{% trans 'Customers' %}</a></li>
                                    <li><a href="{% url lfs_orders %}">{% trans 'Orders' %}</a></li>
                                    <li><a href="{% url lfs_manage_reviews %}">{% trans 'Reviews' %}</a></li>
                                </ul>
                            </li>
                            <li><a>{% trans 'Marketing' %}</a>
                                <ul>
                                	<li><a href="{% url lfs_manage_featured %}">{% trans 'Featured' %}</a></li>
                                    <li><a href="{% url lfs_manage_rating_mails %}">{% trans 'Rating Mails' %}</a></li>
                                    <li><a href="{% url lfs_manage_marketing %}">{% trans 'Topseller' %}</a></li>
                                    <li><a href="{% url lfs_manage_vouchers %}">{% trans 'Vouchers' %}</a></li>
                                </ul>
                            </li>
                            <li><a>{% trans 'Utils' %}</a>
                                <ul>
                                    <li><a href="{% url lfs_export_dispatcher %}">{% trans 'Export' %}</a></li>
                                    <li><a href="{% url lfs_manage_utils %}">{% trans 'Miscellaneous' %}</a></li>
                                </ul>
                            </li>
                        </ul>
                    </td>
                </tr>
            </table>
        </div>

        <table class="main">
            <tr>
                {% block left-slot-wrapper %}
                    <td class="left-slot">
                        <div class="navigation-wrapper">
                            {% block left_slot %}{% endblock %}
                        </div>
                    </td>
                {% endblock %}
                <td class="middle-slot">
                    {% block content %}{% endblock %}
                </td>
            </tr>
        </table>

        {% block footer %}
            <div class="footer">
                <p>{% trans 'Powered by' %} <a target="_blank" href="http://www.getlfs.com">LFS</a> &mdash; Lightning Fast Shop</p>
                <p>
                    <a target="_blank" href="http://www.getlfs.com">LFS</a> {% trans 'is a product of' %} <a target="_blank" href="http://www.iqpp.de">IQ++</a>
                    &mdash; &copy; 2009 - 2011 {% trans 'by' %} <a target="_blank" href="http://www.iqpp.de">IQ++</a> &mdash; {% trans 'All rights reserved' %}
                </p>
                <p>{% trans 'Distributed under the' %} <a target="_blank" href="http://www.opensource.org/licenses/bsd-license.php">{% trans 'BSD-License' %}</a></p>
            </div>
        {% endblock %}

        <div id="dialog" title="LFS Dialog"></div>

        <div class="delete-dialog" title='{% trans "Please Confirm" %}' id="delete-dialog">
            <p class="message">{% trans "Do you really want to delete this object?" %}</p>

            <form action="."
                  method="POST">
                {% csrf_token %}
                <div class="dialog-buttons">
                    <button class="dialog-yes-button button">{% trans "Yes" %}</button>
                    <button class="dialog-close-button button">{% trans "No" %}</button>
                </div>
            </form>
        </div>

    </body>
</html>
<script>
    $(".button").button();
</script>
