{% load i18n %}
<h2 class="heading-middle">{% trans 'Select field properties' %}</h2>

<form id="shop-property-select-type-form"
      action="{% url lfs_save_select_field property.id %}"
      method="post">

    {% csrf_token %}
    {% include "manage/lfs_form.html" %}
    
    <div class="buttons">
        <input type="submit"
               value="{% trans 'Save' %}"
               class="button shop-property-input-button"
               name="Save"/>
    </div>
</form>
