{% load i18n %}
<form action="{% url lfs_edit_portlet portletassigment_id %}"
      method="post">
    <div class="field">
        <div class="label">
            <label>{% trans 'Position' %}:</label>
        </div>        
        <div>
            <input type="text"
                   name="position"
                   value="{{ position }}">
        </div>
    </div>
    <div class="field">
        <div class="label">
            <label>{% trans 'Slot' %}:</label>
        </div>
        <div>
            <select name="slot">
                {% for slot in slots %}
                    <option value="{{ slot.id }}"
                        {% if slot.selected %}selected="selected"{% endif %}>
                        {{ slot.name }}
                    </option>
                {% endfor %}
            </select>
        </div>
    </div>
        
    {% include "manage/lfs_form.html" %}
    
    <input class="ajax-save-button button"
           type="submit"
           value="{% trans 'Save portlet' %}" />
</form>