{% extends "manage/manage_base.html" %}
{% load i18n %}

{% block section %}manage-featured-products{% endblock %}
{% block left-slot-wrapper %}{% endblock %}

{% block content %}    
    <div id="product">
        <div id="manage-tabs">
            <ul>
                <li class="ui-tabs-nav-item"><a href="#featured">{% trans 'Featured Products' %}</a></li>                
            </ul>

            <div id="featured">
                {{ featured|safe }}
            </div>                        
        </div>
    </div>
{% endblock %}