{% load i18n %}

<h2>{% trans "Vouchers" %}</h2>

<div id="vouchers-inline">
    {{ vouchers_inline|safe }}
</div>

<h2 style="padding-top:20px">{% trans "Add vouchers" %}</h2>
<form action="{% url lfs_manage_add_vouchers voucher_group.id %}"
      method="post">

    {% include "manage/lfs_form.html" %}

    <div class="buttons">
        <input class="padding-top ajax-save-button button"
               type="submit"
               value='{% trans "Add vouchers" %}'>
    </div>
</form>

