{% extends "manage/manage_base.html" %}
{% load i18n %}

{% block section %}add-voucher-group{% endblock %}
{% block left-slot-wrapper %}{% endblock %}

{% block content %}
    <div id="manage-tabs">
        <ul>
            <li class="ui-tabs-nav-item"><a href="#data">{% trans 'Add voucher group' %}</a></li>            
        </ul>

        <div id="data">
            <h2>{% trans 'Add voucher group' %}</h2>

            <form action="{% url lfs_manage_add_voucher_group %}"
                  method="post">
                {% csrf_token %}  
                {% include "manage/lfs_form.html" %}

                <input type="submit"
                       class="button"
                       value="{% trans 'Add voucher group' %}" />
                       
                    {% if  request.META.HTTP_REFERER %}                       
                        <input type="button"
                               class="button"
                               onclick="window.location='{{ request.META.HTTP_REFERER }}'"
                               value="{% trans 'Cancel' %}" />
                    {% endif %}
            </form>
        </div>
    </div>    
{% endblock %}