{% load i18n %}
{% load lfs_manage_tags %}

<table class="lfs-manage-table" style="margin-bottom:0">
    <tr>
        <td width="50%">
            <h2>{% trans "Products" %}</h2>
            <form id="category-products-filter-form"
                  action="{% url lfs_manage_category_products_inline category.id %}"
                  onsubmit="return false">

                <input type="hidden"
                       name="keep-session"
                       value="1" />

                <input class="refresh-on-keyup"
                       type="text"
                       name="filter" />

                {% category_filter "refresh-on-change" "category_filter" %}

                <select class="refresh-on-change"
                        name="category-products-amount">
                    {% for option in amount_options %}
                        <option {% if option.selected %}selected="selected"{% endif %}
                                value="{{ option.value }}">{{ option.value }}</option>
                    {% endfor %}
                </select>

            </form>
        </td>
        <td width="50%">
            <h2>{% trans "Selected Products" %}</h2>

            <form id="category-selected-products-filter-form"
                  action="{% url lfs_selected_products category.id %}"
                  onsubmit="return false">

                <input type="hidden"
                       name="keep-session"
                       value="1" />

                <input class="refresh-on-keyup"
                       type="text"
                       name="filter_2" />
            </form>
        </td>
    </tr>
</table>

<span id="products-inline">
    {{ products_inline }}
</span>