{% extends "manage/manage_base.html" %}
{% load i18n %}

{% block section %}manage-discount{% endblock %}
{% block left_slot %}
    <h2 class="navigation-title">
        {% trans "Discounts" %}
    </h2>
    <div class="navigation-body"
         id="discounts">
        {{ navigation|safe }}
    </div>
{% endblock %}

{% block content %}
    <div class="site-actions">
        <a class="add"
           href="{% url lfs_manage_add_discount %}">
            {% trans 'Add discount' %}</a>

        <a class="delete delete-link"
           dialog_message="{% trans 'Do you really want to delete this discount?' %}"
           href="{% url lfs_manage_delete_discount discount.id %}">
            {% trans 'Delete discount' %}</a>
    </div>

    <div id="manage-tabs">
        <ul>
            <li class="ui-tabs-nav-item"><a href="#data">{% trans 'Discount' %}</a></li>
            <li class="ui-tabs-nav-item"><a href="#criteria">{% trans 'Criteria' %}</a></li>
        </ul>

        <div id="data">
            {{ data }}
        </div>

        <div id="criteria">
            {{ criteria }}
        </div>
    </div>
{% endblock %}