{% extends "manage/manage_base.html" %}
{% load i18n lfs_tags lfs_manage_tags %}

{% block title %}{% trans "Manage Products" %}{% endblock %}
{% block section %}manage-products{% endblock %}
{% block left-slot-wrapper %}{% endblock %}

{% block content %}

	<div id="pages-inline">
		{{ pages_inline|safe }}
	</div>

	<div id="product-filters">
		{{ product_filters }}
	</div>
        
    <div id="manage-tabs">
        <ul>
            <li><a href="#products">{% trans 'Products' %}</a></li>                
        </ul>
        <div id="products">
            <div id="products-inline">
                {{ products_inline|safe }}
            </div>
        </div>                        
    </div>

{% endblock %}


