{% extends "manage/manage_base.html" %}
{% load i18n %}
{% load lfs_tags %}

{% block title %}{% trans "Manage Carts" %}{% endblock %}
{% block section %}manage-carts{% endblock %}
{% block left-slot-wrapper %}{% endblock %}

{% block content %}
    <div id="manage-tabs">
        <ul>
            <li class="ui-tabs-nav-item"><a href="#carts">{% trans 'Carts' %}</a></li>
        </ul>
        <div id="carts">
            <h2>{% trans "Carts" %}</h2>            
            <div id="carts-inline">
                {{ carts_inline|safe }}
            </div>
        </div>
    </div>
{% endblock %}