{% extends "manage/manage_base.html" %}
{% load i18n %}

{% block sextion %}add-tax{% endblock %}
{% block left-slot-wrapper %}{% endblock %}

{% block content %}
    <div id="manage-tabs">
        <ul>
            <li class="ui-tabs-nav-item"><a href="#data">{% trans 'Add tax' %}</a></li>
        </ul>
        <div id="data">
            <h2>{% trans "Data" %}</h2>
            <form action="{% url lfs_add_tax %}"
                  method="post">

                {% csrf_token %}
                {% include "manage/lfs_form.html" %}

                <div class="buttons">
                    <input type="submit"
                           class="button"
                           value="{% trans 'Add' %}">

                    <input type="button"
                           class="button"
                           onclick="window.location='{{ next }}'"
                           value="{% trans 'Cancel' %}" />

                    <input type="hidden"
                           name="next"
                           value="{{ next }}" />

                </div>
            </form>
        </div>
    </div>
{% endblock %}