{% load i18n %}
{% if categories %}
    <ul class="manage-categories">
        {% for category in categories %}
            <li>
                <input type="checkbox" 
                       name="categories"
                       value="{{ category.id }}"
                       {% if category.checked %}checked="checked"{% endif %} />
                <a href="{% url lfs_manage_category category.id %}">
                    {{ category.name }}
                </a>            
                {{ category.children }}
            </li>
        {% endfor %}
    </ul>
{% endif %}