{% load i18n %}
<h2 class="navigation-title">
    {% trans "Payment methods" %}
</h2>

<div class="navigation-body">
    {% for payment_method in payment_methods %}
        <div>
            <a class="selectable {% ifequal current_id payment_method.id %}selected{% endifequal %}" 
               href="{% url lfs_manage_payment_method payment_method.id %}">
                {{ payment_method.name }}
            </a>
        </div>    
    {% endfor %}
</div>
