{% load i18n %}
<div class="navigation-pages">

    {% if page.has_previous %}
        <a class="ajax-link"
           href="{% url lfs_selectable_reviews_inline %}?page=1">
            <img src="{{ STATIC_URL }}icons/resultset_first.png"
                 alt="{% trans 'First' %}"
                 title="{% trans 'First' %}" />
        </a>
        <a class="ajax-link"
           href="{% url lfs_selectable_reviews_inline %}?page={{page.previous_page_number}}">
            <img src="{{ STATIC_URL }}icons/resultset_previous.png"
                 alt="{% trans 'Previous' %}"
                 title="{% trans 'Previous' %}" />
        </a>
    {% else %}
        <span>
            <img src="{{ STATIC_URL }}icons/resultset_first.png"
                 alt="{% trans 'First' %}"
                 title="{% trans 'First' %}" />
        </span>
        <span>
            <img src="{{ STATIC_URL }}icons/resultset_previous.png"
                 alt="{% trans 'Previous' %}"
                 title="{% trans 'Previous' %}" />
        </span>
    {% endif %}

    {{page.number}}  {% trans 'of' %} {{paginator.num_pages}}

    {% if page.has_next %}
        <a class="ajax-link"
           href="{% url lfs_selectable_reviews_inline %}?page={{page.next_page_number}}">
            <img src="{{ STATIC_URL }}icons/resultset_next.png"
                 alt="{% trans 'Next' %}"
                 title="{% trans 'Next' %}" />
        </a>
        <a class="ajax-link"
           href="{% url lfs_selectable_reviews_inline %}?page={{paginator.num_pages}}">
            <img src="{{ STATIC_URL }}icons/resultset_last.png"
                 alt="{% trans 'Last' %}"
                 title="{% trans 'Last' %}" />
        </a>
    {% else %}
        <img src="{{ STATIC_URL }}icons/resultset_next.png"
             alt="{% trans 'Next' %}"
             title="{% trans 'Next' %}" />
        <img src="{{ STATIC_URL }}icons/resultset_last.png"
             alt="{% trans 'Last' %}"
             title="{% trans 'Last' %}" />
    {% endif %}
</div>

{% for review in page.object_list %}
    <div>
        <a href="{% url lfs_manage_review review.id %}"
           class="selectable {% ifequal review_id review.id %}selected{% endifequal %}">
			{{ review.creation_date|date:"d.m.Y - H:i" }}
        </a>
    </div>
{% endfor %}
