{% extends "manage/manage_base.html" %}
{% load i18n %}

{% block section %}utilities{% endblock %}
{% block left-slot-wrapper %}{% endblock %}

{% block content %}    
    <div id="product">
        <div id="manage-tabs">
            <ul>
                <li class="ui-tabs-nav-item"><a href="#utilities">{% trans 'Utilities' %}</a></li>                
            </ul>

            <div id="utilities">

                <h2>{% trans 'Utilities' %}</h2>
                <ul>
                    <li>
                        <a href="{% url lfs_clear_cache %}">{% trans 'Clear Cache' %}</a>
                    </li>
                    <li>
                        <a href="{% url lfs_set_category_levels %}">{% trans 'Set category levels' %}</a>
                    </li>
                    <li>
                        <a href="{% url lfs_reindex_topseller %}">{% trans 'Reindex topseller' %}</a>
                    </li>
                </ul>
            </div>
        </div>
    </div>        
{% endblock %}
