{% extends "manage/manage_base.html" %}
{% load i18n %}
{% load lfs_tags %}

{% block section %}manage-orders{% endblock %}
{% block left-slot-wrapper %}{% endblock %}

{% block content %}
    <div id="manage-tabs">
        <ul>
            <li class="ui-tabs-nav-item"><a href="#orders">{% trans 'Orders' %}</a></li>
        </ul>
    	<div id="orders">
        	<div id="orders-inline">
        		{{ orders_inline|safe }}
        	</div>
    	</div>
    </div>
{% endblock %}